# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ftarot/bot.proto\x12\x05tarot\"L\n\rMessageAction\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x03url\x18\x02 \x01(\tH\x00\x12\x12\n\x08\x63\x61llback\x18\x03 \x01(\tH\x00\x42\t\n\x07payload\"\x87\x01\n\x12SendMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12%\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x14.tarot.MessageAction\x12\x15\n\rrecipient_ids\x18\x03 \x03(\x03\x12\x15\n\x08hook_tag\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_hook_tag\"L\n\x11MessageSentStatus\x12\x14\n\x0crecipient_id\x18\x01 \x01(\x03\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.tarot.SentStatus\"A\n\x13SendMessageResponse\x12*\n\x08statuses\x18\x01 \x03(\x0b\x32\x18.tarot.MessageSentStatus*\xa6\x01\n\x11MessageActionType\x12#\n\x1fMESSAGE_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MESSAGE_ACTION_TYPE_URL\x10\x01\x12 \n\x1cMESSAGE_ACTION_TYPE_CALLBACK\x10\x02\x12-\n)MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED\x10\x03*t\n\nSentStatus\x12\x1b\n\x17SENT_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10SENT_STATUS_SENT\x10\x01\x12\x15\n\x11SENT_STATUS_ERROR\x10\x02\x12\x1c\n\x18SENT_STATUS_USER_BLOCKED\x10\x03\x32T\n\nBotManager\x12\x46\n\x0bSendMessage\x12\x19.tarot.SendMessageRequest\x1a\x1a.tarot.SendMessageResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEACTIONTYPE']._serialized_start=388
  _globals['_MESSAGEACTIONTYPE']._serialized_end=554
  _globals['_SENTSTATUS']._serialized_start=556
  _globals['_SENTSTATUS']._serialized_end=672
  _globals['_MESSAGEACTION']._serialized_start=26
  _globals['_MESSAGEACTION']._serialized_end=102
  _globals['_SENDMESSAGEREQUEST']._serialized_start=105
  _globals['_SENDMESSAGEREQUEST']._serialized_end=240
  _globals['_MESSAGESENTSTATUS']._serialized_start=242
  _globals['_MESSAGESENTSTATUS']._serialized_end=318
  _globals['_SENDMESSAGERESPONSE']._serialized_start=320
  _globals['_SENDMESSAGERESPONSE']._serialized_end=385
  _globals['_BOTMANAGER']._serialized_start=674
  _globals['_BOTMANAGER']._serialized_end=758
# @@protoc_insertion_point(module_scope)
