# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/spread.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tarot/spread.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"w\n\x12TarotSpreadRequest\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x19\n\x11spread_profile_id\x18\x03 \x01(\t\x12\x15\n\x08language\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\"I\n\x13TarotSpreadResponse\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0e\n\x06spread\x18\x03 \x01(\t\"}\n\x18TarotSpreadConfigRequest\x12\x19\n\x11spread_profile_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08question\x18\x03 \x01(\t\x12\x15\n\x08language\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\">\n\x19TarotSpreadConfigResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rspread_prompt\x18\x02 \x01(\t\"Y\n\x11SpreadHistoryItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12 \n\x04role\x18\x02 \x01(\x0e\x32\x12.tarot.MessageRole\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"\xb3\x01\n\x11SaveSpreadRequest\x12\x19\n\x11spread_profile_id\x18\x01 \x01(\t\x12\x0e\n\x06spread\x18\x02 \x01(\t\x12\x10\n\x08question\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x15\n\x08language\x18\x05 \x01(\tH\x00\x88\x01\x01\x12+\n\thistories\x18\x06 \x03(\x0b\x32\x18.tarot.SpreadHistoryItemB\x0b\n\t_language*q\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x16\n\x12MESSAGE_ROLE_HUMAN\x10\x02\x12\x13\n\x0fMESSAGE_ROLE_AI\x10\x03\x32\xfe\x01\n\x0bTarotReader\x12M\n\x12RequestTarotSpread\x12\x19.tarot.TarotSpreadRequest\x1a\x1a.tarot.TarotSpreadResponse\"\x00\x12V\n\x0fGetSpreadConfig\x12\x1f.tarot.TarotSpreadConfigRequest\x1a .tarot.TarotSpreadConfigResponse\"\x00\x12H\n\x12SaveCustomerSpread\x12\x18.tarot.SaveSpreadRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.spread_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEROLE']._serialized_start=718
  _globals['_MESSAGEROLE']._serialized_end=831
  _globals['_TAROTSPREADREQUEST']._serialized_start=58
  _globals['_TAROTSPREADREQUEST']._serialized_end=177
  _globals['_TAROTSPREADRESPONSE']._serialized_start=179
  _globals['_TAROTSPREADRESPONSE']._serialized_end=252
  _globals['_TAROTSPREADCONFIGREQUEST']._serialized_start=254
  _globals['_TAROTSPREADCONFIGREQUEST']._serialized_end=379
  _globals['_TAROTSPREADCONFIGRESPONSE']._serialized_start=381
  _globals['_TAROTSPREADCONFIGRESPONSE']._serialized_end=443
  _globals['_SPREADHISTORYITEM']._serialized_start=445
  _globals['_SPREADHISTORYITEM']._serialized_end=534
  _globals['_SAVESPREADREQUEST']._serialized_start=537
  _globals['_SAVESPREADREQUEST']._serialized_end=716
  _globals['_TAROTREADER']._serialized_start=834
  _globals['_TAROTREADER']._serialized_end=1088
# @@protoc_insertion_point(module_scope)
