# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tarot import spread_pb2 as tarot_dot_spread__pb2


class TarotReaderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RequestTarotSpread = channel.unary_unary(
                '/tarot.TarotReader/RequestTarotSpread',
                request_serializer=tarot_dot_spread__pb2.TarotSpreadRequest.SerializeToString,
                response_deserializer=tarot_dot_spread__pb2.TarotSpreadResponse.FromString,
                )
        self.GetSpreadConfig = channel.unary_unary(
                '/tarot.TarotReader/GetSpreadConfig',
                request_serializer=tarot_dot_spread__pb2.TarotSpreadConfigRequest.SerializeToString,
                response_deserializer=tarot_dot_spread__pb2.TarotSpreadConfigResponse.FromString,
                )
        self.SaveCustomerSpread = channel.unary_unary(
                '/tarot.TarotReader/SaveCustomerSpread',
                request_serializer=tarot_dot_spread__pb2.SaveSpreadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class TarotReaderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RequestTarotSpread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpreadConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveCustomerSpread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TarotReaderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RequestTarotSpread': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestTarotSpread,
                    request_deserializer=tarot_dot_spread__pb2.TarotSpreadRequest.FromString,
                    response_serializer=tarot_dot_spread__pb2.TarotSpreadResponse.SerializeToString,
            ),
            'GetSpreadConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpreadConfig,
                    request_deserializer=tarot_dot_spread__pb2.TarotSpreadConfigRequest.FromString,
                    response_serializer=tarot_dot_spread__pb2.TarotSpreadConfigResponse.SerializeToString,
            ),
            'SaveCustomerSpread': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveCustomerSpread,
                    request_deserializer=tarot_dot_spread__pb2.SaveSpreadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.TarotReader', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TarotReader(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RequestTarotSpread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/RequestTarotSpread',
            tarot_dot_spread__pb2.TarotSpreadRequest.SerializeToString,
            tarot_dot_spread__pb2.TarotSpreadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpreadConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/GetSpreadConfig',
            tarot_dot_spread__pb2.TarotSpreadConfigRequest.SerializeToString,
            tarot_dot_spread__pb2.TarotSpreadConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveCustomerSpread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.TarotReader/SaveCustomerSpread',
            tarot_dot_spread__pb2.SaveSpreadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
