# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/validation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16tarot/validation.proto\x12\x05tarot\"\x91\x01\n\x11ValidationRequest\x12\x1d\n\x04type\x18\x01 \x01(\x0e\x32\x0f.tarot.DataType\x12\r\n\x05input\x18\x02 \x01(\t\x12\x19\n\x0c\x65xtra_prompt\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08language\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_extra_promptB\x0b\n\t_language\"U\n\x12ValidationResponse\x12\x10\n\x08is_valid\x18\x01 \x01(\x08\x12\x16\n\x0eunified_result\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\"m\n\x1dValidateSpreadQuestionRequest\x12\r\n\x05input\x18\x01 \x01(\t\x12\x19\n\x11question_category\x18\x02 \x01(\t\x12\x15\n\x08language\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language*x\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x44\x41TA_TYPE_FULL_NAME\x10\x01\x12\x19\n\x15\x44\x41TA_TYPE_BIRTH_PLACE\x10\x02\x12\x1d\n\x19\x44\x41TA_TYPE_BIRTH_DATE_TIME\x10\x03\x32\xb0\x01\n\nValidation\x12\x45\n\x0cValidateData\x12\x18.tarot.ValidationRequest\x1a\x19.tarot.ValidationResponse\"\x00\x12[\n\x16ValidateSpreadQuestion\x12$.tarot.ValidateSpreadQuestionRequest\x1a\x19.tarot.ValidationResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.validation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DATATYPE']._serialized_start=379
  _globals['_DATATYPE']._serialized_end=499
  _globals['_VALIDATIONREQUEST']._serialized_start=34
  _globals['_VALIDATIONREQUEST']._serialized_end=179
  _globals['_VALIDATIONRESPONSE']._serialized_start=181
  _globals['_VALIDATIONRESPONSE']._serialized_end=266
  _globals['_VALIDATESPREADQUESTIONREQUEST']._serialized_start=268
  _globals['_VALIDATESPREADQUESTIONREQUEST']._serialized_end=377
  _globals['_VALIDATION']._serialized_start=502
  _globals['_VALIDATION']._serialized_end=678
# @@protoc_insertion_point(module_scope)
