# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/chats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tarot/chats.proto\x12\x05tarot\"\xda\x01\n\x12SaveMessageRequest\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12*\n\tdirection\x18\x03 \x01(\x0e\x32\x17.tarot.MessageDirection\x12\x18\n\x0b\x61ttachments\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdate_time\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nmessage_id\x18\x06 \x01(\x03H\x02\x88\x01\x01\x42\x0e\n\x0c_attachmentsB\x0c\n\n_date_timeB\r\n\x0b_message_id\"*\n\x13SaveMessageResponse\x12\x13\n\x0binternal_id\x18\x01 \x01(\t*\x8d\x01\n\x10MessageDirection\x12!\n\x1dMESSAGE_DIRECTION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMESSAGE_DIRECTION_CUSTOMER\x10\x01\x12\x19\n\x15MESSAGE_DIRECTION_BOT\x10\x02\x12\x1b\n\x17MESSAGE_DIRECTION_ADMIN\x10\x03\x32O\n\x05\x43hats\x12\x46\n\x0bSaveMessage\x12\x19.tarot.SaveMessageRequest\x1a\x1a.tarot.SaveMessageResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.chats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MESSAGEDIRECTION']._serialized_start=294
  _globals['_MESSAGEDIRECTION']._serialized_end=435
  _globals['_SAVEMESSAGEREQUEST']._serialized_start=29
  _globals['_SAVEMESSAGEREQUEST']._serialized_end=247
  _globals['_SAVEMESSAGERESPONSE']._serialized_start=249
  _globals['_SAVEMESSAGERESPONSE']._serialized_end=291
  _globals['_CHATS']._serialized_start=437
  _globals['_CHATS']._serialized_end=516
# @@protoc_insertion_point(module_scope)
