# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bots_master.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/bots_master.proto\x12\x05tarot\"8\n\tBotRegion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tlanguages\x18\x03 \x03(\t\"X\n\x03\x42ot\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0csecret_token\x18\x03 \x01(\t\x12!\n\x07regions\x18\x04 \x03(\x0b\x32\x10.tarot.BotRegion\"0\n\x14RetrieveBotsResponse\x12\x18\n\x04\x62ots\x18\x01 \x03(\x0b\x32\n.tarot.Bot\"\x18\n\nBotRequest\x12\n\n\x02id\x18\x01 \x01(\t2L\n\nBotsMaster\x12>\n\x0cRetrieveBots\x12\x11.tarot.BotRequest\x1a\x1b.tarot.RetrieveBotsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bots_master_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOTREGION']._serialized_start=34
  _globals['_BOTREGION']._serialized_end=90
  _globals['_BOT']._serialized_start=92
  _globals['_BOT']._serialized_end=180
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_start=182
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_end=230
  _globals['_BOTREQUEST']._serialized_start=232
  _globals['_BOTREQUEST']._serialized_end=256
  _globals['_BOTSMASTER']._serialized_start=258
  _globals['_BOTSMASTER']._serialized_end=334
# @@protoc_insertion_point(module_scope)
