# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tarot/users.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"\xbb\x01\n\x0cTelegramUser\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0e\n\x06is_bot\x18\x07 \x01(\x08\x12\x12\n\nis_premium\x18\x08 \x01(\x08\x12\x16\n\x0eprofile_photos\x18\t \x03(\t\x12\x13\n\x0b\x63ustomer_id\x18\n \x01(\t\"\xd0\x02\n\rSpreadProfile\x12\r\n\x05tg_id\x18\x01 \x01(\x03\x12\x1e\n\x11spread_profile_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tfull_name\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nbirth_date\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x62irth_place\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bzodiac_sign\x18\x06 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x63hinese_zodiac_sign\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x13\n\x06gender\x18\x08 \x01(\tH\x06\x88\x01\x01\x42\x14\n\x12_spread_profile_idB\x0c\n\n_full_nameB\r\n\x0b_birth_dateB\x0e\n\x0c_birth_placeB\x0e\n\x0c_zodiac_signB\x16\n\x14_chinese_zodiac_signB\t\n\x07_gender\"\x92\x01\n\x12GetCustomerRequest\x12\x18\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05tg_id\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1e\n\x11spread_profile_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x08\n\x06_tg_idB\x14\n\x12_spread_profile_id\"=\n\x15\x43reateCustomerRequest\x12$\n\x07tg_user\x18\x01 \x01(\x0b\x32\x13.tarot.TelegramUser\"Y\n\x17\x43ustomerLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x15\n\x0b\x63ustomer_id\x18\x02 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x03 \x01(\x03H\x00\x42\x04\n\x02id\"\xfa\x01\n\x0f\x43ustomerProfile\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x07tg_user\x18\x02 \x01(\x0b\x32\x13.tarot.TelegramUserH\x01\x88\x01\x01\x12\x31\n\x0espread_profile\x18\x03 \x01(\x0b\x32\x14.tarot.SpreadProfileH\x02\x88\x01\x01\x12\x1b\n\x0e\x61\x63tual_balance\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x15\n\x08language\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_tg_userB\x11\n\x0f_spread_profileB\x11\n\x0f_actual_balanceB\x0b\n\t_language\"5\n\x0f\x43ustomerBalance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x63tual_balance\x18\x02 \x01(\x05\"\xb6\x01\n\x13\x43ustomerTransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.tarot.TransactionType\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x05\x12\r\n\x05price\x18\x05 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\"H\n\x14\x43ustomerTransactions\x12\x30\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1a.tarot.CustomerTransaction\"\xc6\x01\n\x13TopUpBalanceRequest\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x02 \x01(\x03H\x00\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x05\x12\r\n\x05price\x18\x04 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12,\n\x1fpayment_provider_transaction_id\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\x04\n\x02idB\"\n _payment_provider_transaction_id\"G\n\x17InternalPurchaseRequest\x12\x15\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00\x12\x0f\n\x05tg_id\x18\x02 \x01(\x03H\x00\x42\x04\n\x02id\"7\n\x1d\x43ommitInternalPurchaseRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\"C\n\x17RegisterReferralRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x13\n\x0breferrer_id\x18\x02 \x01(\t*n\n\x0fTransactionType\x12 \n\x1cTRANSACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17TRANSACTION_TYPE_INCOME\x10\x01\x12\x1c\n\x18TRANSACTION_TYPE_OUTCOME\x10\x02*\x96\x01\n\x11TransactionStatus\x12\"\n\x1eTRANSACTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTRANSACTION_STATUS_SUCCESS\x10\x01\x12\x1e\n\x1aTRANSACTION_STATUS_PENDING\x10\x02\x12\x1d\n\x19TRANSACTION_STATUS_FAILED\x10\x03\x32\xea\x08\n\x05Users\x12\x46\n\x0e\x43reateCustomer\x12\x1c.tarot.CreateCustomerRequest\x1a\x16.tarot.CustomerProfile\x12@\n\x0bGetCustomer\x12\x19.tarot.GetCustomerRequest\x1a\x16.tarot.CustomerProfile\x12P\n\x16UpdateCustomerLanguage\x12\x1e.tarot.CustomerLanguageRequest\x1a\x16.tarot.CustomerProfile\x12>\n\x12\x43reateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x0fGetTelegramUser\x12\x19.tarot.GetCustomerRequest\x1a\x13.tarot.TelegramUser\x12>\n\x12UpdateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x13UpdateSpreadProfile\x12\x14.tarot.SpreadProfile\x1a\x14.tarot.SpreadProfile\x12\x43\n\x10GetSpreadProfile\x12\x19.tarot.GetCustomerRequest\x1a\x14.tarot.SpreadProfile\x12G\n\x12GetCustomerBalance\x12\x19.tarot.GetCustomerRequest\x1a\x16.tarot.CustomerBalance\x12Q\n\x17GetCustomerTransactions\x12\x19.tarot.GetCustomerRequest\x1a\x1b.tarot.CustomerTransactions\x12\x42\n\x0cTopUpBalance\x12\x1a.tarot.TopUpBalanceRequest\x1a\x16.tarot.CustomerBalance\x12V\n\x18InitiateInternalPurchase\x12\x1e.tarot.InternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12Z\n\x16\x43ommitInternalPurchase\x12$.tarot.CommitInternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12Z\n\x16RevertInternalPurchase\x12$.tarot.CommitInternalPurchaseRequest\x1a\x1a.tarot.CustomerTransaction\x12J\n\x10RegisterReferral\x12\x1e.tarot.RegisterReferralRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRANSACTIONTYPE']._serialized_start=1856
  _globals['_TRANSACTIONTYPE']._serialized_end=1966
  _globals['_TRANSACTIONSTATUS']._serialized_start=1969
  _globals['_TRANSACTIONSTATUS']._serialized_end=2119
  _globals['_TELEGRAMUSER']._serialized_start=58
  _globals['_TELEGRAMUSER']._serialized_end=245
  _globals['_SPREADPROFILE']._serialized_start=248
  _globals['_SPREADPROFILE']._serialized_end=584
  _globals['_GETCUSTOMERREQUEST']._serialized_start=587
  _globals['_GETCUSTOMERREQUEST']._serialized_end=733
  _globals['_CREATECUSTOMERREQUEST']._serialized_start=735
  _globals['_CREATECUSTOMERREQUEST']._serialized_end=796
  _globals['_CUSTOMERLANGUAGEREQUEST']._serialized_start=798
  _globals['_CUSTOMERLANGUAGEREQUEST']._serialized_end=887
  _globals['_CUSTOMERPROFILE']._serialized_start=890
  _globals['_CUSTOMERPROFILE']._serialized_end=1140
  _globals['_CUSTOMERBALANCE']._serialized_start=1142
  _globals['_CUSTOMERBALANCE']._serialized_end=1195
  _globals['_CUSTOMERTRANSACTION']._serialized_start=1198
  _globals['_CUSTOMERTRANSACTION']._serialized_end=1380
  _globals['_CUSTOMERTRANSACTIONS']._serialized_start=1382
  _globals['_CUSTOMERTRANSACTIONS']._serialized_end=1454
  _globals['_TOPUPBALANCEREQUEST']._serialized_start=1457
  _globals['_TOPUPBALANCEREQUEST']._serialized_end=1655
  _globals['_INTERNALPURCHASEREQUEST']._serialized_start=1657
  _globals['_INTERNALPURCHASEREQUEST']._serialized_end=1728
  _globals['_COMMITINTERNALPURCHASEREQUEST']._serialized_start=1730
  _globals['_COMMITINTERNALPURCHASEREQUEST']._serialized_end=1785
  _globals['_REGISTERREFERRALREQUEST']._serialized_start=1787
  _globals['_REGISTERREFERRALREQUEST']._serialized_end=1854
  _globals['_USERS']._serialized_start=2122
  _globals['_USERS']._serialized_end=3252
# @@protoc_insertion_point(module_scope)
