# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tarot import bot_pb2 as tarot_dot_bot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10tarot/task.proto\x12\x05tarot\x1a\x0ftarot/bot.proto\"\xa1\x01\n\x13ScheduleTaskRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x04type\x18\x02 \x01(\x0e\x32\x0f.tarot.TaskType\x12*\n\x07payload\x18\x03 \x01(\x0b\x32\x19.tarot.SendMessageRequest\x12\x17\n\rdue_timestamp\x18\x04 \x01(\x03H\x00\x42\n\n\x08scheduleB\x07\n\x05_name\"\x92\x01\n\x14ScheduleTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\t\x12\x1d\n\x04type\x18\x04 \x01(\x0e\x32\x0f.tarot.TaskType\x12!\n\x06status\x18\x05 \x01(\x0e\x32\x11.tarot.TaskStatusB\x07\n\x05_name*\x92\x01\n\nTaskStatus\x12\x1b\n\x17TASK_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13TASK_STATUS_PENDING\x10\x01\x12\x1b\n\x17TASK_STATUS_IN_PROGRESS\x10\x02\x12\x19\n\x15TASK_STATUS_COMPLETED\x10\x03\x12\x16\n\x12TASK_STATUS_FAILED\x10\x04*c\n\x08TaskType\x12\x19\n\x15TASK_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16TASK_TYPE_SEND_MESSAGE\x10\x01\x12 \n\x1cTASK_TYPE_SEND_BATCH_MESSAGE\x10\x02\x32X\n\x0bTaskManager\x12I\n\x0cScheduleTask\x12\x1a.tarot.ScheduleTaskRequest\x1a\x1b.tarot.ScheduleTaskResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKSTATUS']._serialized_start=358
  _globals['_TASKSTATUS']._serialized_end=504
  _globals['_TASKTYPE']._serialized_start=506
  _globals['_TASKTYPE']._serialized_end=605
  _globals['_SCHEDULETASKREQUEST']._serialized_start=45
  _globals['_SCHEDULETASKREQUEST']._serialized_end=206
  _globals['_SCHEDULETASKRESPONSE']._serialized_start=209
  _globals['_SCHEDULETASKRESPONSE']._serialized_end=355
  _globals['_TASKMANAGER']._serialized_start=607
  _globals['_TASKMANAGER']._serialized_end=695
# @@protoc_insertion_point(module_scope)
